from bluer_ai.help.generic import help_functions as generic_help_functions
from bluer_ai.help.actions import help_perform_action
from bluer_ai.help.assets import help_functions as help_assets
from bluer_ai.help.blueness import help_blueness
from bluer_ai.help.browse import help_browse
from bluer_ai.help.conda import help_functions as help_conda
from bluer_ai.help.clone import help_clone
from bluer_ai.help.docker import help_functions as help_docker
from bluer_ai.help.download import help_download
from bluer_ai.help.env import help_functions as help_env
from bluer_ai.help.eval import help_eval
from bluer_ai.help.gif import help_gif
from bluer_ai.help.git import help_functions as help_git
from bluer_ai.help.gpu import help_functions as help_gpu
from bluer_ai.help.host import help_functions as help_host
from bluer_ai.help.init import help_init
from bluer_ai.help.instance import help_functions as help_instance
from bluer_ai.help.latex import help_functions as help_latex
from bluer_ai.help.logging import help_cat
from bluer_ai.help.logging import help_functions as help_log
from bluer_ai.help.list import help_functions as help_list
from bluer_ai.help.ls import help_ls
from bluer_ai.help.metadata import help_functions as help_metadata
from bluer_ai.help.mlflow import help_functions as help_mlflow
from bluer_ai.help.notebooks import help_functions as help_notebooks
from bluer_ai.help.object import help_functions as help_object
from bluer_ai.help.open import help_open
from bluer_ai.help.pause import help_pause
from bluer_ai.help.plugins import help_functions as help_plugins
from bluer_ai.help.publish import help_functions as help_publish
from bluer_ai.help.repeat import help_repeat
from bluer_ai.help.sagemaker import help_functions as help_sagemaker
from bluer_ai.help.seed import help_functions as help_seed
from bluer_ai.help.select import help_select
from bluer_ai.help.session import help_functions as help_session
from bluer_ai.help.storage import help_functions as help_storage
from bluer_ai.help.sleep import help_sleep
from bluer_ai.help.source import (
    help_source_caller_suffix_path,
    help_source_path,
)
from bluer_ai.help.terminal import help_badge
from bluer_ai.help.terraform import help_functions as help_terraform
from bluer_ai.help.upload import help_upload
from bluer_ai.help.watch import help_watch

help_functions = generic_help_functions(plugin_name="bluer_ai")


help_functions.update(
    {
        "assets": help_assets,
        "badge": help_badge,
        "blueness": help_blueness,
        "browse": help_browse,
        "cat": help_cat,
        "clone": help_clone,
        "conda": help_conda,
        "docker": help_docker,
        "download": help_download,
        "env": help_env,
        "eval": help_eval,
        "gif": help_gif,
        "git": help_git,
        "gpu": help_gpu,
        "host": help_host,
        "init": help_init,
        "instance": help_instance,
        "latex": help_latex,
        "log": help_log,
        "list": help_list,
        "ls": help_ls,
        "metadata": help_metadata,
        "mlflow": help_mlflow,
        "notebooks": help_notebooks,
        "object": help_object,
        "open": help_open,
        "pause": help_pause,
        "perform_action": help_perform_action,
        "plugins": help_plugins,
        "publish": help_publish,
        "repeat": help_repeat,
        "sagemaker": help_sagemaker,
        "seed": help_seed,
        "select": help_select,
        "sleep": help_sleep,
        "session": help_session,
        "storage": help_storage,
        "source_caller_suffix_path": help_source_caller_suffix_path,
        "source_path": help_source_path,
        "terraform": help_terraform,
        "upload": help_upload,
        "watch": help_watch,
    }
)



from typing import List

from bluer_options.terminal import show_usage


def help_read(
    tokens: List[str],
    mono: bool,
) -> str:
    return show_usage(
        [
            "@mlflow",
            "cache",
            "read",
            "<keyword>",
        ],
        "read mlflow.cache[<keyword>].",
        mono=mono,
    )


def help_write(
    tokens: List[str],
    mono: bool,
) -> str:
    return show_usage(
        [
            "@mlflow",
            "cache",
            "write",
            "<keyword>",
            "<value>",
        ],
        "write mlflow.cache[<keyword>]=value.",
        mono=mono,
    )


help_functions = {
    "read": help_read,
    "write": help_write,
}



from typing import List

from bluer_options.terminal import show_usage, xtra


def help_select(
    tokens: List[str],
    mono: bool,
) -> str:
    options = xtra("open,type=<type>", mono=mono)

    return show_usage(
        [
            "@select",
            "[-|<object-name>]",
            f"[{options}]",
        ],
        "select <object-name>.",
        mono=mono,
    )



from typing import List

from bluer_options.terminal import show_usage, xtra

from bluer_ai.help.mlflow.cache import help_functions as help_cache
from bluer_ai.help.mlflow.tags import help_functions as help_tags
from bluer_ai import env


def help_browse(
    tokens: List[str],
    mono: bool,
) -> str:
    options = "databricks,experiment,host,models"

    return show_usage(
        [
            "@mlflow",
            "browse",
            f"[{options}]",
            "[.|<object-name>]",
        ],
        "browse mlflow.",
        mono=mono,
    )


def help_get_id(
    tokens: List[str],
    mono: bool,
) -> str:
    return show_usage(
        [
            "@mlflow",
            "get_id",
            "[.|<object-name>]",
        ],
        "get mlflow id for <object-name>.",
        mono=mono,
    )


def help_get_run_id(
    tokens: List[str],
    mono: bool,
) -> str:
    args = [
        "[--count <1>]",
        "[--delim <space>]",
        "[--offset <0>]",
    ]

    return show_usage(
        [
            "@mlflow",
            "get_run_id",
            "[.|<object-name>]",
        ]
        + args,
        "get mlflow run ids for <object-name>.",
        mono=mono,
    )


def help_list_registered_models(
    tokens: List[str],
    mono: bool,
) -> str:
    return show_usage(
        [
            "@mlflow",
            "list_registered_models",
        ],
        "list mlflow registered models.",
        mono=mono,
    )


def help_log_artifacts(
    tokens: List[str],
    mono: bool,
) -> str:
    args = ["[--model_name <model-name>]"]

    return show_usage(
        [
            "@mlflow",
            "log_artifacts",
            "[.|<object-name>]",
        ]
        + args,
        "<object-name> -artifacts-> mlflow.",
        mono=mono,
    )


def help_log_run(
    tokens: List[str],
    mono: bool,
) -> str:
    return show_usage(
        [
            "@mlflow",
            "log_run",
            "[.|<object-name>]",
        ],
        "<object-name> -run-> mlflow.",
        mono=mono,
    )


def help_rm(
    tokens: List[str],
    mono: bool,
) -> str:
    return show_usage(
        [
            "@mlflow",
            "rm",
            "[.|<object-name>]",
        ],
        "rm <object-name> from mlflow.",
        mono=mono,
    )


def help_run(
    tokens: List[str],
    mono: bool,
) -> str:
    return show_usage(
        [
            "@mlflow",
            "run",
            "start | end",
            "[.|<object-name>]",
        ],
        "start | end mlflow run.",
        mono=mono,
    )


def help_test(
    tokens: List[str],
    mono: bool,
) -> str:
    options = xtra("dryrun", mono=mono)

    return show_usage(
        [
            "@mlflow",
            "test",
            f"[{options}]",
        ],
        "test mlflow.",
        mono=mono,
    )


def help_transition(
    tokens: List[str],
    mono: bool,
) -> str:
    options = "model=<model-name>,stage=<stage>,version=<version>"

    return show_usage(
        [
            "@mlflow",
            "transition",
            f"[{options}]",
            "[<description>]",
        ],
        "transition <model-name>.",
        {
            "stage: {}".format(" | ".join(env.ABCLI_MLFLOW_STAGES.split("|"))): "",
        },
        mono=mono,
    )


help_functions = {
    "browse": help_browse,
    "cache": help_cache,
    "get_id": help_get_id,
    "get_run_id": help_get_run_id,
    "list_registered_models": help_list_registered_models,
    "log_artifacts": help_log_artifacts,
    "log_run": help_log_run,
    "rm": help_rm,
    "run": help_run,
    "tags": help_tags,
    "test": help_test,
    "transition": help_transition,
}



from typing import List

from bluer_options.terminal import show_usage, xtra


def help_get(
    tokens: List[str],
    mono: bool,
) -> str:
    options = "name"

    return show_usage(
        [
            "@host",
            "get",
            f"[{options}]",
        ],
        "get $abcli_host_name.",
        mono=mono,
    )


def help_reboot(
    tokens: List[str],
    mono: bool,
) -> str:
    options = xtra("dryrun", mono=mono)

    return show_usage(
        [
            "@host",
            "reboot",
            f"[{options}]",
        ],
        "reboot host.",
        mono=mono,
    )


def help_shutdown(
    tokens: List[str],
    mono: bool,
) -> str:
    options = xtra("dryrun", mono=mono)

    return show_usage(
        [
            "@host",
            "shutdown",
            f"[{options}]",
        ],
        "shutdown host.",
        mono=mono,
    )


help_functions = {
    "get": help_get,
    "reboot": help_reboot,
    "shutdown": help_shutdown,
}



from typing import List

from bluer_options.terminal import show_usage, xtra


def help_pause(
    tokens: List[str],
    mono: bool,
) -> str:
    options = xtra(
        "dryrun,message=<dash-separated-message>",
        mono=mono,
    )

    return show_usage(
        [
            "@pause",
            f"[{options}]",
        ],
        "show <message> and pause for key press.",
        mono=mono,
    )



import argparse

from blueness import module
from blueness.argparse.generic import sys_exit

from bluer_ai import NAME
from bluer_ai.plugins.gpu import get_status, validate
from bluer_ai.logger import logger

NAME = module.name(__file__, NAME)

parser = argparse.ArgumentParser(NAME)
parser.add_argument(
    "task",
    type=str,
    help="status|validate",
)
args = parser.parse_args()

success = False
if args.task == "status":
    success = True
    print(str(get_status()).lower())
elif args.task == "validate":
    success = validate()
else:
    success = None

sys_exit(logger, NAME, args.task, success)



from typing import List

from bluer_options.terminal import show_usage, xtra


def help_create(
    tokens: List[str],
    mono: bool,
) -> str:
    options = "".join(
        [
            xtra("clone=<auto|base>,~install_plugin,", mono=mono),
            "name=<environment-name>",
            xtra(",repo=<repo-name>,~recreate", mono=mono),
        ]
    )

    return show_usage(
        [
            "@conda",
            "create",
            f"[{options}]",
        ],
        "create conda environment.",
        mono=mono,
    )


def help_exists(
    tokens: List[str],
    mono: bool,
) -> str:
    options = "name=<environment-name>"

    return show_usage(
        [
            "@conda",
            "exists",
            f"[{options}]",
        ],
        "does conda environment exist?",
        mono=mono,
    )


def help_list(
    tokens: List[str],
    mono: bool,
) -> str:
    options = xtra("dryrun", mono=mono)

    return show_usage(
        [
            "@conda",
            "list",
            f"[{options}]",
        ],
        "show list of conda environments.",
        mono=mono,
    )


def help_rm(
    tokens: List[str],
    mono: bool,
) -> str:
    options = "".join(
        [
            xtra("dryrun,", mono=mono),
            "name=<environment-name>",
        ]
    )

    return show_usage(
        [
            "@conda",
            "rm",
            f"[{options}]",
        ],
        "rm conda environment.",
        mono=mono,
    )


help_functions = {
    "create": help_create,
    "exists": help_exists,
    "list": help_list,
    "rm": help_rm,
}



from typing import List

from bluer_options.terminal import show_usage, xtra


def help_gif(
    tokens: List[str],
    mono: bool,
) -> str:
    options = xtra("~download,dryrun,~upload", mono=mono)

    args = [
        "[--frame_duration <150>]",
        "[--output_filename <object-name>.gif]",
        "[--scale <1>]",
        "[--suffix <.png>]",
    ]

    return show_usage(
        [
            "@gif",
            f"[{options}]",
            "[.|<object-name>]",
        ]
        + args,
        "generate <object-name>.gif.",
        mono=mono,
    )



from bluer_objects import file, path

from bluer_ai.plugins.git import version


def test_git_increment_version():
    assert version.increment(
        path.absolute(
            "../../",
            file.path(__file__),
        )
    )



import os

from bluer_options.env import load_config, load_env

load_env(__name__)
load_config(__name__)


abcli_is_github_workflow = os.getenv("GITHUB_ACTIONS", "")

abcli_blue_sbc_application = os.getenv("abcli_blue_sbc_application", "")

abcli_display_fullscreen = os.getenv("abcli_display_fullscreen", "")

bluer_ai_git_ssh_key_name = os.getenv("bluer_ai_git_ssh_key_name", "")

bluer_ai_gpu = os.getenv("bluer_ai_gpu", "")

ABCLI_MESSENGER_RECIPIENTS = os.getenv("ABCLI_MESSENGER_RECIPIENTS", "")

abcli_path_abcli = os.getenv("abcli_path_abcli", "")

ABCLI_PATH_IGNORE = os.getenv("ABCLI_PATH_IGNORE", "")

VANWATCH_TEST_OBJECT = os.getenv("VANWATCH_TEST_OBJECT", "vanwatch-test-object-v2")

ABCLI_MLFLOW_STAGES = os.getenv("ABCLI_MLFLOW_STAGES", "")



from typing import List

from bluer_options.terminal import show_usage, xtra


def help_get(
    tokens: List[str],
    mono: bool,
) -> str:
    # ---
    options = "".join(
        [
            xtra("delim=+,dict.keys,dict.values,", mono=mono),
            "filename,key=<key>",
        ]
    )
    usage_1 = show_usage(
        [
            "@metadata",
            "get",
            f"[{options}]",
            "<filename.yaml>",
        ],
        "get <filename.yaml>[<key>]",
        mono=mono,
    )

    # ---
    options = "".join(
        [
            xtra("delim=+,dict.keys,dict.values,filename=<metadata.yaml>,", mono=mono),
            "key=<key>,object",
        ]
    )
    usage_2 = show_usage(
        [
            "@metadata",
            "get",
            f"[{options}]",
            "[.|<object-name>]",
        ],
        "get <object-name>/metadata[<key>]",
        mono=mono,
    )

    # ---
    options = "".join(
        [
            xtra("delim=+,dict.keys,dict.values,filename=<metadata.yaml>,", mono=mono),
            "key=<key>,path",
        ]
    )
    usage_3 = show_usage(
        [
            "@metadata",
            "get",
            f"[{options}]",
            "<path>",
        ],
        "get <path>/metadata[<key>]",
        mono=mono,
    )

    return "\n".join(
        [
            usage_1,
            usage_2,
            usage_3,
        ]
    )


def help_post(
    tokens: List[str],
    mono: bool,
) -> str:
    args = ["[--verbose 1]"]

    # ---
    options = "filename"

    usage_1 = show_usage(
        [
            "@metadata",
            "post",
            "<key>",
            "<value>",
            f"{options}",
            "<filename.yaml>",
        ]
        + args,
        "<filename.yaml>[<key>] = <value>",
        mono=mono,
    )

    # ---
    options = "".join(
        [
            "object",
            xtra(",filename=<metadata.yaml>", mono=mono),
        ]
    )

    usage_2 = show_usage(
        [
            "@metadata",
            "post",
            "<key>",
            "<value>",
            f"{options}",
            "[.|<object-name>]",
        ]
        + args,
        "<object-name>[<key>] = <value>",
        mono=mono,
    )

    # ---
    options = "".join(
        [
            "path",
            xtra(",filename=<metadata.yaml>", mono=mono),
        ]
    )

    usage_3 = show_usage(
        [
            "@metadata",
            "post",
            "<key>",
            "<value>",
            f"{options}",
            "<path>",
        ]
        + args,
        "<path>[<key>] = <value>",
        mono=mono,
    )

    return "\n".join(
        [
            usage_1,
            usage_2,
            usage_3,
        ]
    )


help_functions = {
    "get": help_get,
    "post": help_post,
}



from typing import List

from bluer_options.terminal import show_usage


def help_perform_action(
    tokens: List[str],
    mono: bool,
) -> str:
    options = "action=<action-name>,plugin=<plugin-name>"

    return show_usage(
        [
            "@perform_action",
            f"[{options}]",
            "<args>",
        ],
        "perform the action.",
        mono=mono,
    )



from typing import List

from bluer_options.terminal import show_usage, xtra

instance_type_details = {
    "instance-type: t2.xlarge | p2.xlarge (gpu)": [],
}


def help_from_image(
    tokens: List[str],
    mono: bool,
) -> str:
    options = "image=<image-name>,ssh,vnc"

    return show_usage(
        [
            "@instance",
            "from_image",
            "<instance-type>",
            "<instance-name>",
            f"[{options}]",
        ],
        "create ec2 instance from <image-name>.",
        instance_type_details,
        mono=mono,
    )


def help_from_template(
    tokens: List[str],
    mono: bool,
) -> str:
    options = "ssh,vnc"

    return show_usage(
        [
            "@instance",
            "from_template",
            "<template-name>",
            "<instance-type>",
            "<instance-name>",
            f"[{options}]",
        ],
        "create ec2 instance from <template-name>.",
        instance_type_details,
        mono=mono,
    )


def help_get_ip(
    tokens: List[str],
    mono: bool,
) -> str:
    return show_usage(
        [
            "@instance",
            "get_ip",
            "<instance-name>",
        ],
        "get <instance-name> ip address.",
        mono=mono,
    )


def help_list(
    tokens: List[str],
    mono: bool,
) -> str:
    options = "images | instances | templates"

    return show_usage(
        [
            "@instance",
            "list",
            f"[{options}]",
        ],
        "list.",
        mono=mono,
    )


def help_terminate(
    tokens: List[str],
    mono: bool,
) -> str:
    return show_usage(
        [
            "@instance",
            "terminate",
            "<instance-id>",
        ],
        "terminate <instance-id>.",
        mono=mono,
    )


help_functions = {
    "from_image": help_from_image,
    "from_template": help_from_template,
    "get_ip": help_get_ip,
    "list": help_list,
    "terminate": help_terminate,
}



from typing import List

from bluer_options.terminal import show_usage, xtra


def help_open(
    tokens: List[str],
    mono: bool,
) -> str:
    return show_usage(
        [
            "@object",
            "open",
            "[.|<object-name>]",
        ],
        "open object.",
        mono=mono,
    )


help_functions = {
    "open": help_open,
}



from typing import List

from bluer_options.terminal import show_usage, xtra


def help_publish(
    tokens: List[str],
    mono: bool,
) -> str:
    options = xtra(
        "as=<public-object-name>,~download,prefix=<prefix>,suffix=<.png>",
        mono=mono,
    )

    return show_usage(
        [
            "@publish",
            f"[{options}]",
            "[.|<object-name>]",
        ],
        "publish <object-name>.",
        mono=mono,
    )


def help_publish_tar(
    tokens: List[str],
    mono: bool,
) -> str:
    options = "".join(
        [
            xtra("as=<public-object-name>,~download,", mono=mono),
            "tar",
        ]
    )

    return show_usage(
        [
            "@publish",
            f"[{options}]",
            "[.|<object-name>]",
        ],
        "publish <object-name>.tar.gz.",
        mono=mono,
    )


help_functions = {
    "": help_publish,
    "tar": help_publish_tar,
}



from typing import List

from bluer_options.host import signature as bluer_options_signature
from bluer_objects import fullname as bluer_objects_fullname

from bluer_ai import fullname


def signature() -> List[str]:
    return [
        fullname(),
        bluer_objects_fullname(),
    ] + bluer_options_signature()



from typing import List

from bluer_options.terminal import show_usage, xtra

search_args = [
    "[--count <-1>]",
    "[--delim <space>]",
    "[--log <0>]",
    "[--offset <0>]",
]


def help_clone(
    tokens: List[str],
    mono: bool,
) -> str:
    return show_usage(
        [
            "@mlflow",
            "tags",
            "clone",
            "[..|<object-1>]",
            "[.|<object-2>]",
        ],
        "clone mlflow tags.",
        mono=mono,
    )


def help_get(
    tokens: List[str],
    mono: bool,
) -> str:
    args = ["[--tag <tag>]"]

    return show_usage(
        [
            "@mlflow",
            "tags",
            "get",
            "[.|<object-name>]",
        ]
        + args,
        "get mlflow tags|<tag> for <object-name>.",
        mono=mono,
    )


def help_search(
    tokens: List[str],
    mono: bool,
) -> str:
    options = "explicit"

    usage_1 = show_usage(
        [
            "@mlflow",
            "tags",
            "search",
            f"[{options}]",
        ]
        + search_args
        + ["[--filter_string <filter-string>]"],
        "search mlflow for <filter-string>",
        {
            "<finter-string>: https://www.mlflow.org/docs/latest/search-experiments.html": ""
        },
        mono=mono,
    )

    # ---

    options = "<keyword-1>=<value-1>,<keyword-2>,~<keyword-3>"

    usage_2 = show_usage(
        [
            "@mlflow",
            "tags",
            "search",
            f"[{options}]",
        ]
        + search_args,
        "search mlflow.",
        mono=mono,
    )

    return "\n".join(
        [
            usage_1,
            usage_2,
        ]
    )


def help_set(
    tokens: List[str],
    mono: bool,
) -> str:
    options = "<keyword-1>=<value>,<keyword-2>,~<keyword-3>"

    return show_usage(
        [
            "@mlflow",
            "tags",
            "set",
            "[.|<object-name>]",
            f"[{options}]",
        ],
        "set tags in mlflow.",
        mono=mono,
    )


help_functions = {
    "clone": help_clone,
    "get": help_get,
    "search": help_search,
    "set": help_set,
}



from typing import List

from bluer_options.terminal import show_usage

from bluer_ai.help.env.backup import help_functions as help_backup
from bluer_ai.help.env.dot import help_functions as help_dot


def help_(
    tokens: List[str],
    mono: bool,
) -> str:
    return show_usage(
        [
            "@env",
            "[keyword]",
        ],
        "show environment variables.",
        mono=mono,
    )


help_functions = {
    "": help_,
    "backup": help_backup,
    "dot": help_dot,
}



from typing import List

from bluer_options.terminal import show_usage, xtra


def help_(
    tokens: List[str],
    mono: bool,
) -> str:
    return show_usage(
        [
            "@terraform",
        ],
        "terraform this machine.",
        mono=mono,
    )


def help_cat(
    tokens: List[str],
    mono: bool,
) -> str:
    return show_usage(
        [
            "@terraform",
            "cat",
        ],
        "cat terraform files.",
        mono=mono,
    )


def help_disable(
    tokens: List[str],
    mono: bool,
) -> str:
    return show_usage(
        [
            "@terraform",
            "disable",
        ],
        "disable terraform.",
        mono=mono,
    )


def help_enable(
    tokens: List[str],
    mono: bool,
) -> str:
    return show_usage(
        [
            "@terraform",
            "enable",
        ],
        "enable terraform.",
        mono=mono,
    )


help_functions = {
    "": help_,
    "cat": help_cat,
    "disable": help_disable,
    "enable": help_enable,
}



from typing import List

from bluer_options.terminal import show_usage


def help_ls(
    tokens: List[str],
    mono: bool,
) -> str:
    return "\n".join(
        [
            show_usage(
                [
                    "@ls",
                    "cloud | local",
                    "<object-name>",
                ],
                "ls <object-name>",
                mono=mono,
            ),
            show_usage(
                [
                    "@ls",
                    "<path>",
                ],
                "ls <path>.",
                mono=mono,
            ),
        ]
    )



from typing import List

from bluer_options.terminal import show_usage

source_path_options = "ignore_error,~log"


def help_source_caller_suffix_path(
    tokens: List[str],
    mono: bool,
) -> str:
    options = source_path_options

    return show_usage(
        [
            "bluer_ai_source_caller_suffix_path",
            "<suffix>",
            f"[{options}]",
        ],
        "source <caller-path>/<suffix>.",
        mono=mono,
    )


def help_source_path(
    tokens: List[str],
    mono: bool,
) -> str:
    options = source_path_options

    return show_usage(
        [
            "bluer_ai_source_path",
            "<path>",
            f"[{options}]",
        ],
        "source <path>.",
        mono=mono,
    )



from typing import List

from bluer_options.terminal import show_usage, xtra


def options(mono: bool):
    return xtra(
        "dryrun,~log,path=<path>",
        mono=mono,
    )


def help_eval(
    tokens: List[str],
    mono: bool,
) -> str:
    return show_usage(
        [
            "@eval",
            f"[{options(mono=mono)}]",
            "<command-line>",
        ],
        "eval <command-line>.",
        mono=mono,
    )



from blueness.pypi import setup

from bluer_ai import NAME, VERSION, DESCRIPTION, REPO_NAME

setup(
    filename=__file__,
    repo_name=REPO_NAME,
    name=NAME,
    version=VERSION,
    description=DESCRIPTION,
    packages=[
        NAME,
        f"{NAME}.help",
        f"{NAME}.help.env",
        f"{NAME}.help.mlflow",
        f"{NAME}.modules",
        f"{NAME}.modules.terraform",
        f"{NAME}.plugins",
        f"{NAME}.plugins.git",
        f"{NAME}.plugins.gpu",
        f"{NAME}.tests",
    ],
    package_data={
        NAME: [
            "config.env",
            "sample.env",
            ".abcli/**/*.sh",
            "assets/**/*",
        ],
    },
)
